#!/bin/bash
echo "Firmware patching script for T-CHL7DEUC 2005.0 firmware"
echo "release #1.05 for Linux / 2011-10-26 by geo650."
echo "========================================================="
echo ""
echo "Ensure extracted T-CHL7DEUC subdirectory from"
echo "the original firmware archive is present"
echo "in the same directory together with this script."
echo ""
echo "Ensure all tools have execution permissions."
echo ""
echo "WARNING! Please STOP in case of any error."
echo "The whole process will take up to 10 minutes."
echo ""
echo "========================================================="
read -p "Press [ENTER] to prepare and patch your firmware."
echo ""

if [ ! -d "./T-CHL7DEUC" ]; then
echo "ERROR: No original firmware directory found!"
 if [ -f "./T-CHL7DEUC.exe" ]; then
 echo "Please extract firmware file first!"
 fi
else

echo "verifying firmware version..."
./tools/geopatcher ./T-CHL7DEUC/image/version_info.txt ./version_info.tmp ./scripts/geo1.txt

if [ $? = 0 ]; then

echo "patching exe firmware file..."
./tools/geopatcher ./T-CHL7DEUC/image/exe.img.enc ./new_exe.img.enc ./scripts/geo2.txt

if [ $? = 0 ]; then

echo "patching appdata firmware file..."
./tools/geopatcher ./T-CHL7DEUC/image/appdata.img.enc ./new_appdata.img.enc ./scripts/geo3.txt

if [ $? = 0 ]; then

echo "- unsquashing appdata..."
./tools/unsquashfs ./new_appdata.img.enc
rm ./new_appdata.img.enc
echo "- updating appdata..."
cp -r ./appdata_files/* ./squashfs-root
echo "- squashing appdata..."
./tools/mksquashfs ./squashfs-root updated_appdata.img.enc -b 65536 -le -all-root
rm -rf ./squashfs-root

./tools/geopatcher ./updated_appdata.img.enc ./new_appdata.img.enc ./scripts/geo4.txt

if [ $? = 0 ]; then

echo ""
echo "patching validinfo.txt"
./tools/geopatcher ./T-CHL7DEUC/image/validinfo.txt ./new_validinfo.txt ./scripts/geo5.txt

if [ $? = 0 ]; then

echo ""
echo "swapping files... (3 files are copied)"
cp ./new_validinfo.txt ./T-CHL7DEUC/image/validinfo.txt
cp ./new_exe.img.enc ./T-CHL7DEUC/image/exe.img.enc
cp ./new_appdata.img.enc ./T-CHL7DEUC/image/appdata.img.enc

echo "deleting temporary file(s)..."
rm ./exe_crc_for_validinfo.txt
rm ./appdata_crc_for_validinfo.txt
rm ./new_validinfo.txt
rm ./new_exe.img.enc
rm ./new_appdata.img.enc
rm ./updated_appdata.img.enc
rm ./version_info.tmp

echo ""
echo "*****************************************************************"
echo "DONE! Firmare files are prepared. Are you ready to flash your TV?"
echo "Put T-CHL7DEUC directory on your pendrive and pray ;-)"
echo "*****************************************************************"
echo ""

fi; fi; fi; fi; fi; fi

read -p "Press [ENTER] to end the script."
